@@ -5,7 +5,7 @@ use warnings;
 package Sub::SymMethod;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.003';
+our $VERSION   = '0.004';
 
 use Exporter::Shiny our @EXPORT = qw( symmethod );
 use Scalar::Util qw( blessed );
@@ -159,7 +159,7 @@ sub dispatch {
 		
 		return if $HOOKED{$target}++;
 		
-		'Role::Hooks'->after_apply( $target, sub {
+		'Role::Hooks'->before_apply( $target, sub {
 			my ( $role, $consumer ) = @_;
 			
 			if ( not 'Role::Hooks'->is_role($consumer) ) {
